@@ -42,12 +42,13 @@ async fn shuffle(
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::Shuffle;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(Shuffle {})
+        Ok(test_examples(Shuffle {})?)
     }
 }
