@@ -759,12 +759,13 @@ fn run_regexes(hash: &HashMap<u32, (&'static str, String)>, contents: &str) -> S
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::*;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(ToHTML {})
+        Ok(test_examples(ToHTML {})?)
     }
 }
