@@ -70,6 +70,8 @@ async fn to_md(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputSt
             column_widths.push(escaped_header_string.len());
             escaped_headers.push(escaped_header_string);
         }
+    } else {
+        column_widths = vec![0; headers.len()]
     }
 
     let mut escaped_rows: Vec<Vec<String>> = Vec::new();
@@ -101,7 +103,15 @@ async fn to_md(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputSt
         escaped_rows.push(escaped_row);
     }
 
-    let output_string = get_output_string(&escaped_headers, &escaped_rows, &column_widths, pretty);
+    let output_string = if (column_widths.is_empty() || column_widths.iter().all(|x| *x == 0))
+        && escaped_rows.is_empty()
+    {
+        String::from("")
+    } else {
+        get_output_string(&escaped_headers, &escaped_rows, &column_widths, pretty)
+            .trim()
+            .to_string()
+    };
 
     Ok(OutputStream::one(ReturnSuccess::value(
         UntaggedValue::string(output_string).into_value(name_tag),
@@ -117,22 +127,22 @@ fn get_output_string(
     let mut output_string = String::new();
 
     if !headers.is_empty() {
-        output_string.push_str("|");
+        output_string.push('|');
 
         for i in 0..headers.len() {
             if pretty {
-                output_string.push_str(" ");
+                output_string.push(' ');
                 output_string.push_str(&get_padded_string(
                     headers[i].clone(),
                     column_widths[i],
                     ' ',
                 ));
-                output_string.push_str(" ");
+                output_string.push(' ');
             } else {
                 output_string.push_str(headers[i].as_str());
             }
 
-            output_string.push_str("|");
+            output_string.push('|');
         }
 
         output_string.push_str("\n|");
@@ -140,55 +150,59 @@ fn get_output_string(
         #[allow(clippy::needless_range_loop)]
         for i in 0..headers.len() {
             if pretty {
-                output_string.push_str(" ");
+                output_string.push(' ');
                 output_string.push_str(&get_padded_string(
                     String::from("-"),
                     column_widths[i],
                     '-',
                 ));
-                output_string.push_str(" ");
+                output_string.push(' ');
             } else {
-                output_string.push_str("-");
+                output_string.push('-');
             }
 
-            output_string.push_str("|");
+            output_string.push('|');
         }
 
-        output_string.push_str("\n");
+        output_string.push('\n');
     }
 
     for row in rows {
         if !headers.is_empty() {
-            output_string.push_str("|");
+            output_string.push('|');
         }
 
         for i in 0..row.len() {
             if pretty {
-                output_string.push_str(" ");
+                output_string.push(' ');
                 output_string.push_str(&get_padded_string(row[i].clone(), column_widths[i], ' '));
-                output_string.push_str(" ");
+                output_string.push(' ');
             } else {
                 output_string.push_str(row[i].as_str());
             }
 
             if !headers.is_empty() {
-                output_string.push_str("|");
+                output_string.push('|');
             }
         }
 
-        output_string.push_str("\n");
+        output_string.push('\n');
     }
 
     output_string
 }
 
 fn get_padded_string(text: String, desired_length: usize, padding_character: char) -> String {
+    let repeat_length = if text.len() > desired_length {
+        0
+    } else {
+        desired_length - text.len()
+    };
+
     format!(
         "{}{}",
         text,
-        padding_character
-            .to_string()
-            .repeat(desired_length - text.len())
+        padding_character.to_string().repeat(repeat_length)
     )
 }
 
